---
jupytext:
  formats: ipynb,md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.13.0
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

# ESA metakernels / CReMA

Consolidated Report on Mission Analysis (CReMA) are ESA mission metakernels containing different orbital and trajectory scenarios. They can be found in the `kernels/mk/` folder in each [SPICE release](https://repos.cosmos.esa.int/socci/projects/SPICE_KERNELS/repos/juice/browse). A plain-text summary is also available on [ESA-Cosmos website](https://www.cosmos.esa.int/web/spice/spice-for-juice).


This collection of metakernels is considered to be the canonic setup required to compute the different orbital tour planned for the mission. It is not mandatory to use them, but they constitute an excellent starting point for the beginner user.

The `moon-coverage` tool provide a collection of shortcuts to pull any CReMA (from any given release) and all its associated kernels directly from ESA archive.

## JUICE mission CReMAs

For JUICE, we can list all the CReMAs available in the latest release, very easily:

```{code-cell}
:tags: [output_scroll]
from moon_coverage import JUICE_CREMAS

JUICE_CREMAS
```

As we can see, the tool automatically query the online ESA archive to get the latest tag publicly published (here `v291_20211210_001`) and pull the list of all the CReMAs available in that release.

The list metakernels is available with the `mks` property:

```{code-cell}
:tags: [output_scroll]
JUICE_CREMAS.mks
```

as well as the name of the mission:

```{code-cell}
JUICE_CREMAS.mission
```

and the generic DOI associated with this kernels dataset:

```{code-cell}
JUICE_CREMAS.doi
```

You can also check if a known metakernel filename is in the latest release:

```{code-cell}
'juice_crema_5_0.tm' in JUICE_CREMAS
```

```{code-cell}
'juice_crema_6_0.tm' in JUICE_CREMAS
```

All the previous releases are available with the `versions` property:

```{code-cell}
:tags: [output_scroll]
JUICE_CREMAS.versions
```

and if you need to list the metakernels available for an older version, you only have to do:

:::{Tip}
:class: margin

You don't need to provide the full release id, usually the version number is sufficient.
:::

```{code-cell}
:tags: [output_scroll]
JUICE_CREMAS.version('v160')
```

When you know which metakernel you want to work with, you can request it by with its name:

```{code-cell}
:tags: [remove-output]
JUICE_CREMAS['juice_crema_5_0.tm']
```
```
PosixPath('~/.moon-coverage-esa-crema/juice/v291_20211210_001/juice_crema_5_0.tm')
```

You will get `pathlib.Path` object pointing to its location on your disk (cached in your home folder). If the file is missing locally, it will be downloaded automatically from the ESA archive.

:::{Tip}

To query a metakernel, you can use its full name or you can use these kind of shortcuts:

```python
>>> JUICE_CREMAS[5.0]
PosixPath('.../v291_20211210_001/juice_crema_5_0.tm')

>>> JUICE_CREMAS['4.2b22.1 (cruise only)']
PosixPath('.../v291_20211210_001/juice_crema_4_2b22_1_cruise.tm')

>>> JUICE_CREMAS['3_2 gan N56 Pp5 Q19']
PosixPath('.../v291_20211210_001/juice_crema_3_2_gan_N56_Pp5_Q19.tm')
```

These keys follow the same pattern as the one listed on [ESA-Cosmos SPICE page](https://www.cosmos.esa.int/web/spice/spice-for-juice).
:::

:::{Hint}
The locally cached metakernel files are sorted by mission and releases. If you need to use a specific `version` of a CReMA, you can add a second argument with its version number:

```python
>>> JUICE_CREMAS['3.2 ops', 'v160']
PosixPath('~/.moon-coverage-esa-crema/juice/v160_20180216_001/juice_crema_3_2_ops.tm')
```

Similarly to the `version()` function, you don't need to provide the full release id, the version is usually enough.

If no explicit version is provided, the tool will search for the latest release available and use that as a default version argument.
:::


Finally, you can consume these metakernels files very easily with the [`MetaKernel`
object](kernels.html#metakernel-object):


```python
from moon_coverage import MetaKernel

MetaKernel(JUICE_CREMAS['5.0', 'v291'], kernels='/data/kernels')
```


## Other ESA missions

The current setup is optimized for the JUICE mission but could be easily extended to other ESA mission. If you want to use the `moon-coverage` tool for another mission, for which the kernels are publicly available on the [ESA-SPICE bitbucket](https://repos.cosmos.esa.int/socci/projects/SPICE_KERNELS), you can defined a new collection of ESA CReMAs like this:

```{code-cell}
:tags: [output_scroll]
from moon_coverage.esa import EsaCremasCollection

EsaCremasCollection('BEPICOLOMBO')
```
