# Installation and updates

The latest version of the `moon-coverage` available
on [Python Package Index](https://pypi.org/project/moon-coverage/) is `0.11.0`.
You can install it very easily with `pip`, either in
a [Jupyter environnement](#installation-in-a-jupyter-environment)
or globally [at the user level](#global-installation).

If you have access to a working [Jupyter environnement](https://jupyter.org/),
ie. a [locally installed JupyterLab](https://blog.jupyter.org/jupyterlab-desktop-app-now-available-b8b661b17e9a)
or a remote JupyterHub like [ESA DataLabs](https://datalabs.esa.int/),
we recommend to use the first method of installation.


## Installation in a Jupyter Environment

In your Jupyter environment, go to `File > New > Notebook` to create a new notebook and in the first cell, type:

```python
%pip install --upgrade moon-coverage
```

Execute the cell with <kbd>⇧ Shift</kbd> + <kbd>↵ Enter</kbd> and you should get the latest version of the `moon-coverage`.

You can double check which version was installed by running the following command:
```python
%pip show moon-coverage
```

## Global installation

If you want to use the `moon-coverage` directly in your terminal or
in your [REPL](https://realpython.com/interacting-with-python),
you can install it globally at the user level. In your terminal, run:

```{code} bash
pip install --user --upgrade moon-coverage
```

## Changes and updates

The `moon-coverage` adheres to [semantic versioning](https://semver.org),
ie. the version number will have the following pattern:
```
MAJOR.MINOR.PATCH
```

Since this package is under active development, new releases are available
on irregular basis.
All the changes are reported in the [changelog section](../CHANGELOG).
If you need to upgrade to a newer version, you only
need to re-run one of the installation command above to get the latest version.

## How to cite this package

If you use this package for your analyses, please consider using the following citation:

> Seignovert, Benoît, Gabriel Tobie, Rozenn Robidel, Claire Vallat, Inès Belgacem, and Nicolas Altobelli.
> Python Moon-Coverage Toolbox, LPG - Nantes Université, 2022.
> Version: 0.11.0, [moon-coverage.univ-nantes.fr](https://moon-coverage.univ-nantes.fr/en/0.11.0/),
> [swh:1:rel:8416d4a23e2d695ce68c35f22aace9281c25dbaa](https://archive.softwareheritage.org/browse/origin/directory/?origin_url=https://juigitlab.esac.esa.int/datalab/moon-coverage&release=0.11.0)

or can use this [BibTeX file](https://juigitlab.esac.esa.int/datalab/moon-coverage/-/raw/main/moon-coverage.bib?inline=false).

## Issues and feedback

If you have any issue with this package, we highly recommend to take a look at:

- [this documentation](../index) (the search bar on the left is there for you)
- [the gallery of examples](../gallery/index)
- [the example notebooks repository](https://juigitlab.esac.esa.int/datalab/moon-coverage-notebooks)

If you did not find a solution there, don't hesitate to:

- [open an issue](https://juigitlab.esac.esa.int/datalab/moon-coverage/-/issues/new), if you have an account on the [JUICE Gitlab](https://juigitlab.esac.esa.int/datalab/moon-coverage)
- send us an email at [&#109;&#111;&#111;&#110;&#45;&#99;&#111;&#118;&#101;&#114;&#97;&#103;&#101;&#64;&#117;&#110;&#105;&#118;&#45;&#110;&#97;&#110;&#116;&#101;&#115;&#46;&#102;&#114;](&#109;&#97;&#105;&#108;&#116;&#111;&#58;&#109;&#111;&#111;&#110;&#45;&#99;&#111;&#118;&#101;&#114;&#97;&#103;&#101;&#64;&#117;&#110;&#105;&#118;&#45;&#110;&#97;&#110;&#116;&#101;&#115;&#46;&#102;&#114;
)


## Bug fix and contributions

The `moon-coverage` is distributed under a open-source
[BSD-3 clauses](https://juigitlab.esac.esa.int/datalab/moon-coverage/-/blob/main/LICENSE.md) license.
Bug reports and contributions are encouraged and always welcome.
If you have an account on the [JUICE Gitlab](https://juigitlab.esac.esa.int/datalab/moon-coverage),
fee free to open [an issue](https://juigitlab.esac.esa.int/datalab/moon-coverage/-/issues/new)
or [a merge request](https://juigitlab.esac.esa.int/datalab/moon-coverage/-/merge_requests/new).
If you don't, send us an email directly at the address above.
