# Moon Coverage Documentation

The [moon-coverage](https://moon-coverage.univ-nantes.fr/gitlab)
python package is a toolbox to perform
surface coverage analysis based on orbital trajectory configuration.
Its main intent is to provide an easy way to compute observation
opportunities of specific region of interest above the Galilean
satellites for the ESA-JUICE mission but could be extended in the
future to other space mission.

It is actively developed by the
[Laboratory of Planetology and Geosciences](https://lpg-umr6112.fr/) (CNRS-UMR 6112)
at Nantes University (France),
under [ESA-JUICE](https://sci.esa.int/web/juice) founding support.

```{image} images/lpg-esa.png
:width: 512
:alt: Logos LPG / CNRS / ESA-JUICE
:align: center
```

```{toctree}
:caption: Get started
:hidden:

get-started/install.md
get-started/kernels.md
get-started/presentation.md
```

```{toctree}
:caption: Trajectory calculations
:hidden:

trajectory/spacecraft/index.md
trajectory/instrument/index.md
trajectory/flybys/index.md
trajectory/rois/index.md
```

```{toctree}
:hidden:
:caption: SPICE tools

spice/kernel.md
spice/mk.md
spice/toolbox.md
spice/times.md
```

```{toctree}
:hidden:
:caption: ESA tools

esa/crema.md
esa/events.md
esa/export.md
```

```{toctree}
:hidden:
:caption: Miscellaneous

gallery/index.rst
maps/index.md
api/index.md
CHANGELOG.md
```

```{toctree}
:hidden:
:caption: Resources
Gitlab repo <https://juigitlab.esac.esa.int/datalab/moon-coverage>
Bug tracker <https://juigitlab.esac.esa.int/datalab/moon-coverage/-/issues>
PyPI <https://pypi.org/project/moon-coverage/>
SWH archive <https://archive.softwareheritage.org/browse/origin/?origin_url=https://juigitlab.esac.esa.int/datalab/moon-coverage>
```
