---
jupytext:
  formats: ipynb,md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.13
    jupytext_version: 1.13.0
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

# Background maps

To facilitate the representation of the data in their context, the `moon-coverage` have a pre-build-in collection of planetary background maps.

```{code-cell}
:tags: [remove-input]

import matplotlib.pyplot as plt
```

:::{Danger}
For the ESA/JUICE mission the longitudes are defined __eastward__ from (0° to 360° to the East). This definition is not consistent with the [IAU report (2018)](https://astropedia.astrogeology.usgs.gov/download/Docs/WGCCRE/WGCCRE2015reprint.pdf) and the [NAIF-SPICE](https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/Tutorials/pdf/individual_docs/17_frames_and_coordinate_systems.pdf) planetographic coordinate system (defined westward for prograde bodies).

See *H. Hoffmann presentation in JUICE SWT#5 (Jan. 2015)* for details. To be consistent with this definition, we only used planetocentric coordinates in this module (see [NAIF tutorial on frames and coordinate systems](https://naif.jpl.nasa.gov/pub/naif/toolkit_docs/Tutorials/pdf/individual_docs/17_frames_and_coordinate_systems.pdf), slide 25).
:::


## Ganymede

:::{Note}
:class: margin

All the background maps are represented here in [equirectangular](https://en.wikipedia.org/wiki/Equirectangular_projection) projection, with $\lambda_0 = 180°$ (central meridian) and $\phi_0 = 0°$ (cental parallel).
:::

```{code-cell}
from moon_coverage import GANYMEDE
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=GANYMEDE);
```

- __Source__: [Kersten et al. 2021 - PSS / DLR](https://doi.org/10.1016/j.pss.2021.105310)
- __Original image size__: 46,080 × 23,039 pixels
- __Instrument__: Voyager ISS / Galileo SSI
- __Equatorial resolution__: 360 m / pixel
- __Mean radius__: 2,631.2 km (from [`pck00010.tpc`][tpc] kernel).


[tpc]: ftp://spiftp.esac.esa.int/data/SPICE/JUICE/kernels/pck/pck00010.tpc

## Callisto

```{code-cell}
from moon_coverage import CALLISTO
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=CALLISTO);
```

- __Source__: [USGS / ESA](https://www.cosmos.esa.int/documents/529384/555314/Callisto_Voyager_GalileoSSI_global_mosaic_1km_E+%282%29.tif)
- __Original image size__: 15,138 × 7,569 pixels
- __Instrument__: Voyager ISS / Galileo SSI
- __Equatorial resolution__: 1 km / pixel
- __Mean radius__: 2,410.3 km (from [`pck00010.tpc`][tpc] kernel).

## Europa

```{code-cell}
from moon_coverage import EUROPA
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=EUROPA);
```

:::{Caution}
:class: margin

The area without data were masked based on the [previously published USGS map](https://astrogeology.usgs.gov/search/map/Europa/Voyager-Galileo%20Europa_Voyager_GalileoSSI_global_mosaic_500m) for Europa.
:::

- __Source__: [NASA / JPL / Björn Jónsson](https://planetary.s3.amazonaws.com/web/assets/pictures/20150218_europa_global_map_20000x10000.jpg)
- __Original image size__: 20,000 × 10,000 pixels
- __Instrument__: Voyager ISS / Galileo SSI
- __Equatorial resolution__: 490 m / pixel
- __Mean radius__: 1,560.8 km  (from [pck00010.tpc][tpc] kernel).


## Io

```{code-cell}
from moon_coverage import IO
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=IO);
```

- __Source__: [USGS ](https://planetarymaps.usgs.gov/mosaic/Io_GalileoSSI-Voyager_Global_Mosaic_ClrMerge_1km.tif)
- __Original image size__: 11,445 × 5,723 pixels
- __Instrument__: Voyager ISS / Galileo SSI
- __Equatorial resolution__: 1 km / pixel
- __Mean radius__: 1,821.5 km  (from [pck00010.tpc][tpc] kernel).


## Jupiter

```{code-cell}
from moon_coverage import JUPITER
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=JUPITER);
```

- __Source__: [JPL PIA07782](https://photojournal.jpl.nasa.gov/tiff/PIA07782.tif)
* __Original image size__: 3,601 ×  1,801 pixels
* __Instrument__: Cassini ISS
* __Equatorial resolution__: 122 km / pixel
- __Mean radius__: 69,911.3 km  (from [pck00010.tpc][tpc] kernel).


## Earth

```{code-cell}
from moon_coverage import EARTH
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=EARTH);
```

- __Source__: [NASA Blue Marble](https://visibleearth.nasa.gov/images/73751/july-blue-marble-next-generation-w-topography-and-bathymetry)
- __Original image size__: 86,400 × 43,200 pixels
- __Instrument__: Terra MODIS
- __Equatorial resolution__: 463 m / pixel
- __Mean radius__: 6,371.0 km  (from [pck00010.tpc][tpc] kernel).


## Moon

```{code-cell}
from moon_coverage import MOON
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=MOON);
```

- __Source__: [USGS](https://planetarymaps.usgs.gov/mosaic/Lunar_LRO_LROC-WAC_Mosaic_global_100m_June2013.tif)
- __Original image size__: 109,164 × 54,582 pixels
- __Instrument__: LRO WAC
- __Equatorial resolution__: 100 m / pixel
- __Mean radius__: 1,737.4 km  (from [pck00010.tpc][tpc] kernel).


## Venus

```{code-cell}
from moon_coverage import VENUS
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=VENUS);
```

- __Source__: [USGS](https://planetarymaps.usgs.gov/mosaic/Venus_Magellan_C3-MDIR_Colorized_Global_Mosaic_4641m.tif)
- __Original image size__: 8,192 × 4,096 pixels
- __Instrument__: C3-MDIR Synthetic Color Mosaic
- __Equatorial resolution__: 4.6 km / pixel
- __Mean radius__: 6,051.8 km  (from [pck00010.tpc][tpc] kernel).


## Mercury

```{code-cell}
from moon_coverage import MERCURY
```
```{code-cell}
:tags: [remove-input]

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=MERCURY);
```

- __Source__: [USGS](https://planetarymaps.usgs.gov/mosaic/Mercury_MESSENGER_MDIS_Basemap_LOI_Mosaic_Global_166m.tif)
- __Original image size__: 46,080 × 92,160 pixels
- __Instrument__: Messenger WAC/NAC at 750 nm
- __Equatorial resolution__: 166 m / pixel
- __Mean radius__: 2,439.7 km  (from [pck00010.tpc][tpc] kernel).


## Custom map

If none of these maps correspond to your needs, you can create your own custom map by providing a `2:1` background image centered a `180°` (preferred) or `0°`.
See [`Map`](../api/plot.html#map) object API for details.

For example, `GANYMEDE` is defined as:

```python
from moon_coverage.maps import Map

GANYMEDE = Map('Ganymede_map_180.jpg', body='Ganymede', radius=2631.2)
```

## Plot data on the Map

All these planetary maps are expected to be used in _matplotlib_ `projection`:

```{code-cell}
:tags: [remove-input]

import matplotlib.pyplot as plt
from matplotlib.path import Path
```
```{code-cell}
lons_e, lats = [180, 150, 120, 150], [30, 50, 30, 10]

polygon = Path([
    (180, 30), (150, 50), (120, 30), (150, 10)
])
```
```{code-cell}
fig = plt.figure(figsize=(12, 9))
ax = fig.add_subplot(projection=GANYMEDE)

ax.plot(lons_e, lats, 'o', color='tab:red')

ax.add_path(polygon, facecolor='tab:orange', edgecolor='tab:green', alpha=.5);
```


## Get a map from the registry

All the default maps above are also available in the `MAPS` registry.
This allows you to load a `Map` programmatically with a string key:

:::{Tip}
:class: margin

The target name key is not case sensitive. You can also use a `SpiceRef` object.
:::

```{code-cell}
from moon_coverage import MAPS

fig = plt.figure(figsize=(12, 9))
fig.add_subplot(projection=MAPS['Europa']);
```
