"""Test ESA CReMA module."""

from pytest import raises

import moon_coverage.esa.crema as esa_api
from moon_coverage.esa import JUICE_CREMAS


def test_esa_cremas_juice(monkeypatch):
    """Test ESA CReMAs collection in the JUICE case."""
    assert JUICE_CREMAS.mission == 'juice'
    assert JUICE_CREMAS.doi == '10.5270/esa-ybmj68p'
    assert str(JUICE_CREMAS) == 'JuiceCremaCollection'

    # Latest tag
    monkeypatch.setattr(esa_api, 'get_tag', lambda *args, **kwargs: 'latest_version')
    assert JUICE_CREMAS.latest == 'latest_version'

    # Check cache
    monkeypatch.setattr(esa_api, 'get_tag', lambda *args, **kwargs: 'new_version')
    assert JUICE_CREMAS.latest == 'latest_version'

    # CReMAs list
    monkeypatch.setattr(esa_api, 'get_mk',
                        lambda *args, **kwargs: ['crema_1.tm', 'crema_2.tm'])

    assert JUICE_CREMAS.mks == ['crema_2.tm', 'crema_1.tm']  # The list is inverted
    assert len(JUICE_CREMAS) == 2

    # __contains__
    assert 'crema_1.tm' in JUICE_CREMAS
    assert 'crema_3.tm' not in JUICE_CREMAS

    # __iter__
    for crema in JUICE_CREMAS:
        assert crema == 'crema_2.tm'
        break

    # Get item for the latest version
    monkeypatch.setattr(esa_api, 'get_mk',
                        lambda *args, version='latest', **kwargs: f'{version}/crema_3.tm')

    assert JUICE_CREMAS[3.0] == 'latest_version/crema_3.tm'
    assert JUICE_CREMAS['3.0'] == 'latest_version/crema_3.tm'

    # Get item for a given version
    assert JUICE_CREMAS['3.0', 'old_version'] == 'old_version/crema_3.tm'

    # Too many arguments
    with raises(KeyError):
        _ = JUICE_CREMAS[3.0, 'latest', 'foo']

    # Get an older list of metakernels based on a given version
    monkeypatch.setattr(esa_api, 'get_mk',
                        lambda *args, **kwargs: ['crema_3.tm', 'crema_4.tm'])

    assert JUICE_CREMAS.version('previous') == ['crema_4.tm', 'crema_3.tm']
    assert JUICE_CREMAS.mks == ['crema_2.tm', 'crema_1.tm']  # From the cache

    # Get all the previous versions
    monkeypatch.setattr(esa_api, 'get_tag', lambda *args, **kwargs: ['v1', 'v2'])
    assert JUICE_CREMAS.versions == ['v1', 'v2']
