"""Test wget module."""

from pathlib import Path

from pytest import fixture, raises

import moon_coverage.misc.download as download
from moon_coverage.misc import wget


DATA = Path(__file__).parent / '..' / 'data'


@fixture
def fname():
    """Default output filename."""
    return DATA / 'wget.txt'


def test_wget(monkeypatch, fname):
    """Test wget file download."""

    if fname.exists():
        fname.unlink()

    # Disable urlretrieve request
    monkeypatch.setattr(download, 'urlretrieve',
                        lambda _, f: f.write_text('foo'))

    assert not fname.exists()

    # The file does not exists locally
    wget('https://example.org/foo', fname)

    assert fname.exists()
    assert fname.read_text() == 'foo'

    # The file does not exists locally
    with raises(FileExistsError):
        wget('https://example.org/foo', fname)

    # Change urlretrieve request output
    monkeypatch.setattr(download, 'urlretrieve',
                        lambda _, f: f.write_text('bar'))

    # Skip download if already exists
    wget('https://example.org/foo', fname, skip=True)

    # Unchanged file
    assert fname.exists()
    assert fname.read_text() == 'foo'

    # Skip download if already exists even-if force is `True`
    wget('https://example.org/foo', fname, skip=True, force=True)

    # Unchanged file
    assert fname.exists()
    assert fname.read_text() == 'foo'

    # Force download if already exists
    wget('https://example.org/foo', fname, force=True)

    # Changed file
    assert fname.exists()
    assert fname.read_text() == 'bar'

    # Clean test data folder
    fname.unlink()
