"""Test ROIs abstract module."""

from pytest import raises

from moon_coverage.rois.abstract import AbstractCollection, AbstractItem


def test_abstract_item():
    """Test abstract item."""
    item = AbstractItem(1)

    assert item.key == 1
    assert str(item) == '1'
    assert item == '1'
    assert item.name == 'Unnamed'
    assert item['name'] == 'Unnamed'

    item = AbstractItem(1, name='None')

    assert item.name == 'Unnamed'

    item = AbstractItem(1, name='foo bar', desc='description')

    assert item.name == 'Foo Bar'
    assert item.desc == 'description'  # pylint: disable=no-member
    assert item['desc'] == 'description'


def test_abstract_collection():
    """Test abstract collection."""
    coll = AbstractCollection()

    assert isinstance(coll.ITEM(1), AbstractItem)

    assert len(coll) == 0
    assert coll.count == 'No abstractitem'

    # Setter
    coll[1] = {'name': 'foo bar', 'desc': 'description'}

    assert len(coll) == 1
    assert coll.count == '1 abstractitem'

    # Getter
    item = coll[1]
    assert isinstance(item, AbstractItem)
    assert item.key == 1
    assert item == '1'
    assert item.name == 'Foo Bar'
    assert item.desc == 'description'  # pylint: disable=no-member

    # Missing item
    with raises(KeyError):
        _ = coll['2']

    # Add empty
    coll['2'] = {}

    # Add ITEM
    item = AbstractItem(key=4, name='Foo')
    assert item.key == 4

    coll[3] = item
    assert item.key == 4       # Item key is unchanged
    assert coll['3'].key == 3  # But the copied item key is updated.

    # Count
    assert len(coll) == 3
    assert coll.count == '3 abstractitems'

    # Iter on values (and not keys like regular dict)
    for item in coll:
        assert isinstance(item, AbstractItem)
        assert item == '1'
        break

    for item in coll.keys():
        assert isinstance(item, str)
        assert item == '1'
        break

    for item in coll.values():
        assert isinstance(item, AbstractItem)
        assert item == '1'
        break

    for key, value in coll.items():
        assert isinstance(key, str)
        assert isinstance(value, AbstractItem)
        assert key == '1'
        assert value == '1'
        break
