"""Test ROI categories."""

from pytest import raises

from moon_coverage.rois import (
    CategoriesCollection, Category, SubCategoriesCollection, SubCategory
)


def test_categories_collection():
    """Test ROIs categories collection."""
    categories = CategoriesCollection()

    categories[1] = {
        'name': 'Potential Cryovolcanic Regions',
        'color': '#FECCCC',
    }

    assert len(categories) == 1

    category = categories['1']

    assert isinstance(category, Category)
    assert str(category) == '1'
    assert category == '1'
    assert category.name == 'Potential Cryovolcanic Regions'
    assert category.color == '#FECCCC'


def test_subcategories_collection():
    """Test ROIs subcategories."""
    subcategories = SubCategoriesCollection()

    subcategories['4.3'] = {
        'name': 'Dome / Anomaleous Dome Craters',
        'color': '#CCCDFD',
        'category': Category(4, name='Impact Crater Morphologies', color='#CB9CFC')
    }

    assert len(subcategories) == 1

    subcategory = subcategories['4.3']

    assert isinstance(subcategory, SubCategory)
    assert str(subcategory) == '4.3'
    assert subcategory == '4.3'
    assert subcategory.name == 'Dome / Anomaleous Dome Craters'
    assert subcategory.color == '#CCCDFD'

    assert isinstance(subcategory.category, Category)
    assert subcategory.category == '4'
    assert subcategory.category.name == 'Impact Crater Morphologies'
    assert subcategory.category.color == '#CB9CFC'

    # Missing required category attribute
    with raises(AttributeError):
        subcategories['4.1'] = {}
